diff --git a/ayanova/devdocs/rando-todo.txt b/ayanova/devdocs/rando-todo.txt
index 96f638fc..1855188f 100644
--- a/ayanova/devdocs/rando-todo.txt
+++ b/ayanova/devdocs/rando-todo.txt
@@ -50,7 +50,7 @@ possible implementation:
{
TKey = "WidgetName",
FieldKey = "widgetname",
- AyaObjectType = (int)AyaType.Widget,
+ AType = (int)AyaType.Widget,
UiFieldDataType = (int)UiFieldDataType.Text,
SqlIdColumnName = "awidget.id",
SqlValueColumnName = "awidget.name",
diff --git a/ayanova/devdocs/todo.txt b/ayanova/devdocs/todo.txt
index 64bae0f4..dedc2f45 100644
--- a/ayanova/devdocs/todo.txt
+++ b/ayanova/devdocs/todo.txt
@@ -58,16 +58,13 @@ todo: v8 migrate additions
## CLIENT MISC ITEMS
+todo: select list templates under global is offering types that don't6 have select lists like memo etc
-
+todo: adm-translations, adm-report templates data tables are skewed to the left due to lack of selection box column making filter icon partially gone off page
+ if has extension then should have selection box otherwise figure out what the dealio is
...................................................................................................................................................................
-todo: rename all variants of naming that hold an AyaType value to "aType" (parameter) / "AType" (not parameter) everywhere front and back
- "ayType", "objectType", "oType" all are used in various areas
- Search for all references to AyaType and then work back from there
- SQL Criteria as well
-
todo: reportClientMetaData in gzapi has DefaultLocale property in it which is just part of the language, can it be removed?
it might be buggy if there is no dash in the language? Is that a thing?
check at server how it's used
diff --git a/ayanova/src/api/gzapi.js b/ayanova/src/api/gzapi.js
index 96afa386..b2b88687 100644
--- a/ayanova/src/api/gzapi.js
+++ b/ayanova/src/api/gzapi.js
@@ -556,7 +556,7 @@ export default {
},
///////////////////////////////////
// POST FILE ATTACHMENTS
- // @param {ayaId:objectid, ayaType:objectType, files:[array of files]}
+ // @param {ayaId:objectid, ayaType:aType, files:[array of files]}
//
async uploadAttachment(at) {
let that = this;
@@ -567,7 +567,7 @@ export default {
data.append(files[i].name, files[i]);
}
- data.append("AttachToObjectType", at.ayaType);
+ data.append("AttachToAType", at.ayaType);
data.append("AttachToObjectId", at.ayaId);
data.append("Notes", at.notes);
data.append("FileData", at.fileData);
@@ -606,7 +606,7 @@ export default {
data.append(files[i].name, files[i]);
}
if (at.ayaType) {
- data.append("ObjectType", at.ayaType);
+ data.append("AType", at.ayaType);
}
if (at.ayaId) {
data.append("ObjectId", at.ayaId);
diff --git a/ayanova/src/api/gzmenu.js b/ayanova/src/api/gzmenu.js
index 03d468a1..9eb7cb8c 100644
--- a/ayanova/src/api/gzmenu.js
+++ b/ayanova/src/api/gzmenu.js
@@ -314,12 +314,12 @@ export default {
// break;
case "review":
//go to list
- // path: "/home-reviews/:objectType?/:objectId?",
+ // path: "/home-reviews/:aType?/:objectId?",
vm.$router.push({
name: "home-reviews",
params: {
- objectType: window.$gz.util.stringToIntOrNull(item.data.ayaType),
+ aType: window.$gz.util.stringToIntOrNull(item.data.ayaType),
objectId: window.$gz.util.stringToIntOrNull(item.data.recordId),
name: item.data.recordName
}
diff --git a/ayanova/src/components/data-table.vue b/ayanova/src/components/data-table.vue
index d83b879f..500a41c1 100644
--- a/ayanova/src/components/data-table.vue
+++ b/ayanova/src/components/data-table.vue
@@ -695,7 +695,7 @@ export default {
selectedRowIds.reverse();
}
return {
- ObjectType: ayaType,
+ AType: ayaType,
selectedRowIds: selectedRowIds,
dataListKey: vm.dataListKey,
filterId: vm.activeFilterId,
diff --git a/ayanova/src/components/extension-delete-control.vue b/ayanova/src/components/extension-delete-control.vue
index 76ead0b3..6e4712b1 100644
--- a/ayanova/src/components/extension-delete-control.vue
+++ b/ayanova/src/components/extension-delete-control.vue
@@ -29,10 +29,10 @@ export default {
await fetchTranslatedText(vm);
//NOTE: if extension doesn't support a particular object add it here to the NoType default
if (
- vm.dataListSelection.ObjectType != 0 &&
- vm.dataListSelection.ObjectType != window.$gz.type.PartInventoryRestock
+ vm.dataListSelection.AType != 0 &&
+ vm.dataListSelection.AType != window.$gz.type.PartInventoryRestock
) {
- vm.rights = window.$gz.role.getRights(vm.dataListSelection.ObjectType);
+ vm.rights = window.$gz.role.getRights(vm.dataListSelection.AType);
}
vm.available = vm.rights.change;
},
diff --git a/ayanova/src/components/extension-export-control.vue b/ayanova/src/components/extension-export-control.vue
index 27aeac5e..19f00443 100644
--- a/ayanova/src/components/extension-export-control.vue
+++ b/ayanova/src/components/extension-export-control.vue
@@ -27,9 +27,8 @@ export default {
methods: {
available() {
return (
- this.dataListSelection.ObjectType != 0 &&
- this.dataListSelection.ObjectType !=
- window.$gz.type.PartInventoryRestock
+ this.dataListSelection.AType != 0 &&
+ this.dataListSelection.AType != window.$gz.type.PartInventoryRestock
);
},
goHelp() {
diff --git a/ayanova/src/components/extension-tags-control.vue b/ayanova/src/components/extension-tags-control.vue
index a69a9a08..43ebccf8 100644
--- a/ayanova/src/components/extension-tags-control.vue
+++ b/ayanova/src/components/extension-tags-control.vue
@@ -46,10 +46,10 @@ export default {
let vm = this;
if (
- vm.dataListSelection.ObjectType != 0 &&
- vm.dataListSelection.ObjectType != window.$gz.type.PartInventoryRestock
+ vm.dataListSelection.AType != 0 &&
+ vm.dataListSelection.AType != window.$gz.type.PartInventoryRestock
) {
- vm.rights = window.$gz.role.getRights(vm.dataListSelection.ObjectType);
+ vm.rights = window.$gz.role.getRights(vm.dataListSelection.AType);
}
vm.available = vm.rights.change;
},
diff --git a/ayanova/src/components/extensions-control.vue b/ayanova/src/components/extensions-control.vue
index 6e0b180e..66221500 100644
--- a/ayanova/src/components/extensions-control.vue
+++ b/ayanova/src/components/extensions-control.vue
@@ -58,7 +58,7 @@ export default {
resolve: null,
reject: null,
dataListSelection: {
- ObjectType: 0,
+ AType: 0,
selectedRowIds: [],
dataListKey: null
},
diff --git a/ayanova/src/components/report-selector-control.vue b/ayanova/src/components/report-selector-control.vue
index 9c1a828e..26c9e186 100644
--- a/ayanova/src/components/report-selector-control.vue
+++ b/ayanova/src/components/report-selector-control.vue
@@ -122,16 +122,14 @@ export default {
if (reportDataOptions == null) {
throw new Error("report-selector:Open missing reportDataOptions");
}
- if (reportDataOptions.ObjectType == null) {
- throw new Error(
- "report-selector:Open - ObjectType is missing or empty"
- );
+ if (reportDataOptions.AType == null) {
+ throw new Error("report-selector:Open - AType is missing or empty");
}
this.reportDataOptions = reportDataOptions;
//get report list from server
let res = await window.$gz.api.get(
- `report/list/${reportDataOptions.ObjectType}`
+ `report/list/${reportDataOptions.AType}`
);
if (res.error) {
// throw new Error(res.error);
diff --git a/ayanova/src/main.js b/ayanova/src/main.js
index fa68ecde..7c94e654 100644
--- a/ayanova/src/main.js
+++ b/ayanova/src/main.js
@@ -28,7 +28,7 @@ import gzapi from "./api/gzapi";
import gzform from "./api/gzform";
import gzformcustomtemplate from "./api/form-custom-template";
import authorizationroles from "./api/authorizationroles";
-import gztype from "./api/ayatype";
+import ayatype from "./api/ayatype";
import gzenums from "./api/enums";
import "@/assets/css/main.css";
@@ -82,7 +82,7 @@ window.$gz = {
translation: translation,
locale: locale,
formCustomTemplate: gzformcustomtemplate,
- type: gztype,
+ type: ayatype,
role: authorizationroles,
enums: gzenums,
eventBus: gzeventbus,
@@ -252,6 +252,9 @@ Vue.prototype.$ay = {
},
util: function() {
return gzutil;
+ },
+ ayt: function() {
+ return ayatype;
}
};
//disable the devtools nag
diff --git a/ayanova/src/router.js b/ayanova/src/router.js
index 8582b230..8706f868 100644
--- a/ayanova/src/router.js
+++ b/ayanova/src/router.js
@@ -175,13 +175,13 @@ export default new Router({
import(/* webpackChunkName: "ay-common" */ "./views/home-reminder.vue")
},
{
- path: "/home-reviews/:objectType?/:objectId?",
+ path: "/home-reviews/:aType?/:objectId?",
name: "home-reviews",
component: () =>
import(/* webpackChunkName: "ay-common" */ "./views/home-reviews.vue")
},
{
- path: "/home-reviews/:recordid/:objectType?/:objectId?",
+ path: "/home-reviews/:recordid/:aType?/:objectId?",
name: "review-edit",
component: () =>
import(/* webpackChunkName: "ay-common" */ "./views/home-review.vue")
@@ -544,13 +544,13 @@ export default new Router({
import(/* webpackChunkName: "acc" */ "./views/acc-tax-code.vue")
},
{
- path: "/acc-service-banks/:objectType?/:objectId?",
+ path: "/acc-service-banks/:aType?/:objectId?",
name: "service-banks",
component: () =>
import(/* webpackChunkName: "acc" */ "./views/acc-service-banks.vue")
},
{
- path: "/acc-service-banks/:recordid/:objectType?/:objectId?",
+ path: "/acc-service-banks/:recordid/:aType?/:objectId?",
name: "service-bank-edit",
component: () =>
import(/* webpackChunkName: "acc" */ "./views/acc-service-bank.vue")
diff --git a/ayanova/src/views/acc-service-bank.vue b/ayanova/src/views/acc-service-bank.vue
index 1e1ad8b6..f67334d3 100644
--- a/ayanova/src/views/acc-service-bank.vue
+++ b/ayanova/src/views/acc-service-bank.vue
@@ -4,7 +4,7 @@
-
+
{{ iconForType }} {{ name }}
@@ -131,16 +131,16 @@ export default {
await vm.getDataFromApi(vm.$route.params.recordid); //let getdata handle loading
} else {
//New record so there has to be a object type and objectId in route
- // path: "/home-service-banks/:recordid/:objectType?/:objectId?",
+ // path: "/home-service-banks/:recordid/:aType?/:objectId?",
vm.obj.objectId = window.$gz.util.stringToIntOrNull(
vm.$route.params.objectId
);
- vm.obj.objectType = window.$gz.util.stringToIntOrNull(
- vm.$route.params.objectType
+ vm.obj.aType = window.$gz.util.stringToIntOrNull(
+ vm.$route.params.aType
);
- if (!vm.obj.objectId || !vm.obj.objectType) {
- throw "ObjectType and ObjectId are required to create a service bank entry";
+ if (!vm.obj.objectId || !vm.obj.aType) {
+ throw "AType and ObjectId are required to create a service bank entry";
}
vm.name = vm.$route.params.name;
@@ -152,7 +152,7 @@ export default {
if (!vm.name) {
vm.name = await window.$gz.api.fetchBizObjectName(
- vm.obj.objectType,
+ vm.obj.aType,
vm.obj.objectId
);
}
@@ -192,7 +192,7 @@ export default {
//I.E. Serial, usertype fields, ACTIVE
//Also, if it's a non-nullable Enum backed field then it should have a valid selection i.e. not zero if there is no zero
/*
- {"data":{"id":1,"concurrency":1387706,"name":"Prepaid for $500 labor","entryDate":"2005-11-27T19:04:00Z","lastEntryDate":null,"objectId":1,"objectType":8,
+ {"data":{"id":1,"concurrency":1387706,"name":"Prepaid for $500 labor","entryDate":"2005-11-27T19:04:00Z","lastEntryDate":null,"objectId":1,"aType":8,
"sourceId":0,"sourceType":55,"incidents":0.0000,"incidentsBalance":0.0000,"lastIncidentsBalance":null,
"currency":500.0000,"currencyBalance":500.0000,"lastCurrencyBalance":null,
"hours":0.0000,"hoursBalance":0.0000,"lastHoursBalance":null}}
@@ -203,7 +203,7 @@ export default {
concurrency: 0,
name: null,
objectId: null,
- objectType: null,
+ aType: null,
sourceId: 0, //default for manual entries
sourceType: window.$gz.type.ServiceBank,
incidents: 0,
@@ -260,13 +260,13 @@ export default {
},
computed: {
iconForType() {
- return window.$gz.util.iconForType(this.obj.objectType);
+ return window.$gz.util.iconForType(this.obj.aType);
}
},
methods: {
navToTarget: function() {
window.$gz.eventBus.$emit("openobject", {
- type: this.obj.objectType,
+ type: this.obj.aType,
id: this.obj.objectId
});
},
@@ -394,7 +394,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.ServiceBank,
+ AType: window.$gz.type.ServiceBank,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/acc-service-banks.vue b/ayanova/src/views/acc-service-banks.vue
index 048d0c07..302898ce 100644
--- a/ayanova/src/views/acc-service-banks.vue
+++ b/ayanova/src/views/acc-service-banks.vue
@@ -1,6 +1,6 @@
-
@@ -39,19 +39,17 @@ export default {
window.$gz.eventBus.$on("menu-click", clickHandler);
vm.objectId = window.$gz.util.stringToIntOrNull(vm.$route.params.objectId);
- vm.objectType = window.$gz.util.stringToIntOrNull(
- vm.$route.params.objectType
- );
+ vm.aType = window.$gz.util.stringToIntOrNull(vm.$route.params.aType);
//OPTIONAL FILTER
- if (vm.objectId && vm.objectId != 0 && vm.objectType) {
+ if (vm.objectId && vm.objectId != 0 && vm.aType) {
//OBJECTID,AYATYPE
- vm.clientCriteria = `${vm.objectId},${vm.objectType}`;
+ vm.clientCriteria = `${vm.objectId},${vm.aType}`;
vm.preFilterMode = {
icon: vm.$route.params.icon,
id: vm.objectId,
- ayatype: vm.objectType,
+ ayatype: vm.aType,
viz: vm.$route.params.viz,
clearable: true
};
@@ -65,13 +63,12 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.ServiceBank,
selectedItems: [],
reload: false,
clientCriteria: undefined,
preFilterMode: null,
objectId: null,
- objectType: null,
+ aType: null,
name: null
};
},
@@ -79,7 +76,7 @@ export default {
methods: {
// navToTarget: function() {
// window.$gz.eventBus.$emit("openobject", {
- // type: this.objectType,
+ // type: this.aType,
// id: this.objectId
// });
// },
@@ -87,7 +84,7 @@ export default {
this.selectedItems = selected;
},
// iconForType() {
- // return window.$gz.util.iconForType(this.objectType, 10);
+ // return window.$gz.util.iconForType(this.aType, 10);
// },
clearPreFilter() {
this.clientCriteria = null;
@@ -112,7 +109,7 @@ async function clickHandler(menuItem) {
name: "service-bank-edit",
params: {
recordid: 0,
- objectType: m.vm.objectType,
+ aType: m.vm.aType,
objectId: m.vm.objectId,
name: m.vm.name
}
@@ -185,7 +182,7 @@ function generateMenu(vm) {
};
if (vm.rights.change) {
- if (vm.objectId && vm.objectType) {
+ if (vm.objectId && vm.aType) {
menuOptions.menuItems.push({
title: "New",
icon: "$ayiPlus",
diff --git a/ayanova/src/views/acc-service-rate.vue b/ayanova/src/views/acc-service-rate.vue
index d99734c7..eccb5be5 100644
--- a/ayanova/src/views/acc-service-rate.vue
+++ b/ayanova/src/views/acc-service-rate.vue
@@ -579,7 +579,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.ServiceRate,
+ AType: window.$gz.type.ServiceRate,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/acc-service-rates.vue b/ayanova/src/views/acc-service-rates.vue
index 6d8e5aa9..4545b7ce 100644
--- a/ayanova/src/views/acc-service-rates.vue
+++ b/ayanova/src/views/acc-service-rates.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.ServiceRate,
+ aType: window.$gz.type.ServiceRate,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/acc-tax-code.vue b/ayanova/src/views/acc-tax-code.vue
index 905fa199..fcdd2f16 100644
--- a/ayanova/src/views/acc-tax-code.vue
+++ b/ayanova/src/views/acc-tax-code.vue
@@ -536,7 +536,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.TaxCode,
+ AType: window.$gz.type.TaxCode,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/acc-tax-codes.vue b/ayanova/src/views/acc-tax-codes.vue
index c882b3f9..6af21674 100644
--- a/ayanova/src/views/acc-tax-codes.vue
+++ b/ayanova/src/views/acc-tax-codes.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.TaxCode,
+ aType: window.$gz.type.TaxCode,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/acc-travel-rate.vue b/ayanova/src/views/acc-travel-rate.vue
index ba9ed36d..776b29ef 100644
--- a/ayanova/src/views/acc-travel-rate.vue
+++ b/ayanova/src/views/acc-travel-rate.vue
@@ -577,7 +577,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.TravelRate,
+ AType: window.$gz.type.TravelRate,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/acc-travel-rates.vue b/ayanova/src/views/acc-travel-rates.vue
index 74cbeb00..449bab2b 100644
--- a/ayanova/src/views/acc-travel-rates.vue
+++ b/ayanova/src/views/acc-travel-rates.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.TravelRate,
+ aType: window.$gz.type.TravelRate,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/adm-attachments.vue b/ayanova/src/views/adm-attachments.vue
index 71e63cd0..e54e9cfa 100644
--- a/ayanova/src/views/adm-attachments.vue
+++ b/ayanova/src/views/adm-attachments.vue
@@ -132,7 +132,7 @@ export default {
);
}
},
- async moveSelected(ayType, ayId) {
+ async moveSelected(aType, ayId) {
let vm = this;
try {
//called from move dialog, already selected
diff --git a/ayanova/src/views/adm-user.vue b/ayanova/src/views/adm-user.vue
index f141013a..df798b9a 100644
--- a/ayanova/src/views/adm-user.vue
+++ b/ayanova/src/views/adm-user.vue
@@ -938,7 +938,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.User,
+ AType: window.$gz.type.User,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/adm-users.vue b/ayanova/src/views/adm-users.vue
index 166a2022..4f98b81f 100644
--- a/ayanova/src/views/adm-users.vue
+++ b/ayanova/src/views/adm-users.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.User,
+ aType: window.$gz.type.User,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/ay-history.vue b/ayanova/src/views/ay-history.vue
index 86e47b99..ab530521 100644
--- a/ayanova/src/views/ay-history.vue
+++ b/ayanova/src/views/ay-history.vue
@@ -25,21 +25,18 @@
>
{{
- getIconForObjectType(i.objectType)
+ getIconForAType(i.aType)
}}{{ getNameForType(i.objectType) }}
+ >{{ getNameForType(i.aType) }}
{{ i.textra }}
{{
$ay.t("History")
}}
- {{ $ay.t("Open") }}
+ {{
+ $ay.t("Open")
+ }}
@@ -62,9 +59,9 @@
>
{{
- getIconForObjectType(i.objectType)
+ getIconForAType(i.aType)
}}{{ getNameForType(i.objectType) }}
+ >{{ getNameForType(i.aType) }}
{{ i.textra }}
@@ -156,7 +153,7 @@ export default {
});
} else {
window.$gz.eventBus.$emit("openobject", {
- type: item.objectType,
+ type: item.aType,
id: item.objectId
});
}
@@ -172,7 +169,7 @@ export default {
} else {
this.$router.push({
name: "ay-history",
- params: { ayatype: item.objectType, recordid: item.objectId }
+ params: { ayatype: item.aType, recordid: item.objectId }
});
}
},
@@ -216,7 +213,7 @@ export default {
getIconForEvent(event) {
return this.eventTypes[event].icon;
},
- getIconForObjectType(otype) {
+ getIconForAType(otype) {
if (otype) {
//return this.ayaTypes[otype].icon;
return window.$gz.util.iconForType(otype);
diff --git a/ayanova/src/views/ay-report-edit.vue b/ayanova/src/views/ay-report-edit.vue
index a210270a..9eeeec1e 100644
--- a/ayanova/src/views/ay-report-edit.vue
+++ b/ayanova/src/views/ay-report-edit.vue
@@ -316,7 +316,7 @@ export default {
await vm.getDataFromApi(vm.$route.params.recordid); //let getdata handle loading
}
} else {
- //New record so there *MUST* be an ayType on the route params
+ //New record so there *MUST* be an aType on the route params
window.$gz.form.setFormState({
vm: vm,
@@ -454,7 +454,7 @@ export default {
active: true,
notes: "",
roles: 124927, //all except customers
- objectType: 0,
+ aType: 0,
template: `
@@ -527,7 +527,7 @@ Handlebars.registerHelper('loud', function (aString) {
};
},
/*{"data":{"id":10,"concurrency":19494847,"name":"test basic","active":true,"notes":"",
- "roles":124927,"objectType":2,
+ "roles":124927,"aType":2,
"template":"\n\n\n\t{{#each ayReportData}}\n\t{{ Name }}
\n\tNotes: {{ Notes }}
\n\t{{/each}}\n\n\n","style":".example {\n color: blue;\n}","jsPrerender":"async function ayPrepareData(reportData){ \n //this function (if present) is called with the report data \n //before the report is rendered\n //modify data as required here and return it to change the data before the report renders\n //see the help documentation for details\n return reportData;\n}","jsHelpers":"//Register custom Handlebars helpers here to use in your report script\n//https://handlebarsjs.com/guide/#custom-helpers\nHandlebars.registerHelper('loud', function (aString) {\n return aString.toUpperCase()\n})",
"renderType":0,
"headerTemplate":null,"footerTemplate":null,"displayHeaderFooter":false,
@@ -1113,12 +1113,12 @@ async function fetchReportData(vm) {
vm.reportData = null;
return;
}
- if (reportDataOptions.ObjectType == null) {
+ if (reportDataOptions.AType == null) {
throw new Error(
- "ay-report-edit:fetchReportData - route parameter ObjectType is missing or empty, unable to init report designer"
+ "ay-report-edit:fetchReportData - route parameter AType is missing or empty, unable to init report designer"
);
}
- vm.obj.objectType = reportDataOptions.ObjectType;
+ vm.obj.aType = reportDataOptions.AType;
let res = await window.$gz.api.upsert("report/data", reportDataOptions);
//We never expect there to be no data here
diff --git a/ayanova/src/views/cust-customer-note.vue b/ayanova/src/views/cust-customer-note.vue
index c700841e..97c61d81 100644
--- a/ayanova/src/views/cust-customer-note.vue
+++ b/ayanova/src/views/cust-customer-note.vue
@@ -400,7 +400,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.CustomerNote,
+ AType: window.$gz.type.CustomerNote,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/cust-customer-notes.vue b/ayanova/src/views/cust-customer-notes.vue
index 6541e6cf..3c7687e0 100644
--- a/ayanova/src/views/cust-customer-notes.vue
+++ b/ayanova/src/views/cust-customer-notes.vue
@@ -2,7 +2,7 @@
@@ -55,7 +55,7 @@ export default {
clientCriteria: undefined,
preFilterMode: null,
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.CustomerNote,
+ aType: window.$gz.type.CustomerNote,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/cust-customer.vue b/ayanova/src/views/cust-customer.vue
index 07b59250..51f45165 100644
--- a/ayanova/src/views/cust-customer.vue
+++ b/ayanova/src/views/cust-customer.vue
@@ -924,7 +924,7 @@ export default {
this.$router.push({
name: "service-banks",
params: {
- objectType: window.$gz.type.Customer,
+ aType: window.$gz.type.Customer,
objectId: this.$route.params.recordid,
viz: this.obj.name,
icon: "$ayiAddressCard"
@@ -1370,7 +1370,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.Customer,
+ AType: window.$gz.type.Customer,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/cust-customers.vue b/ayanova/src/views/cust-customers.vue
index 1325c4aa..f170e1f6 100644
--- a/ayanova/src/views/cust-customers.vue
+++ b/ayanova/src/views/cust-customers.vue
@@ -2,7 +2,7 @@
@@ -35,7 +35,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.Customer,
+ aType: window.$gz.type.Customer,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/cust-head-office.vue b/ayanova/src/views/cust-head-office.vue
index 2c8a0fb8..60135c0d 100644
--- a/ayanova/src/views/cust-head-office.vue
+++ b/ayanova/src/views/cust-head-office.vue
@@ -828,7 +828,7 @@ export default {
this.$router.push({
name: "service-banks",
params: {
- objectType: window.$gz.type.HeadOffice,
+ aType: window.$gz.type.HeadOffice,
objectId: this.$route.params.recordid,
viz: this.obj.name,
icon: "$ayiSitemap"
@@ -1274,7 +1274,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.HeadOffice,
+ AType: window.$gz.type.HeadOffice,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/cust-head-offices.vue b/ayanova/src/views/cust-head-offices.vue
index 6446baea..7709786f 100644
--- a/ayanova/src/views/cust-head-offices.vue
+++ b/ayanova/src/views/cust-head-offices.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.HeadOffice,
+ aType: window.$gz.type.HeadOffice,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/cust-user.vue b/ayanova/src/views/cust-user.vue
index f01a1a4b..bcfef489 100644
--- a/ayanova/src/views/cust-user.vue
+++ b/ayanova/src/views/cust-user.vue
@@ -948,7 +948,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.User,
+ AType: window.$gz.type.User,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/cust-users.vue b/ayanova/src/views/cust-users.vue
index be4be5e4..ad9410b6 100644
--- a/ayanova/src/views/cust-users.vue
+++ b/ayanova/src/views/cust-users.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.User,
+ aType: window.$gz.type.User,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/home-memo.vue b/ayanova/src/views/home-memo.vue
index 82e5ec6c..6d9b30b6 100644
--- a/ayanova/src/views/home-memo.vue
+++ b/ayanova/src/views/home-memo.vue
@@ -567,7 +567,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.Memo,
+ AType: window.$gz.type.Memo,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/home-memos.vue b/ayanova/src/views/home-memos.vue
index d9589481..f6c053d1 100644
--- a/ayanova/src/views/home-memos.vue
+++ b/ayanova/src/views/home-memos.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.Memo,
+ aType: window.$gz.type.Memo,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/home-reminder.vue b/ayanova/src/views/home-reminder.vue
index fd8c999a..eccdc5ad 100644
--- a/ayanova/src/views/home-reminder.vue
+++ b/ayanova/src/views/home-reminder.vue
@@ -523,7 +523,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.Reminder,
+ AType: window.$gz.type.Reminder,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/home-reminders.vue b/ayanova/src/views/home-reminders.vue
index 09c40e39..33d494b7 100644
--- a/ayanova/src/views/home-reminders.vue
+++ b/ayanova/src/views/home-reminders.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.Reminder,
+ aType: window.$gz.type.Reminder,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/home-review.vue b/ayanova/src/views/home-review.vue
index 9c8cb90d..19b0e338 100644
--- a/ayanova/src/views/home-review.vue
+++ b/ayanova/src/views/home-review.vue
@@ -4,7 +4,7 @@
-
+
{{ iconForType }} {{ name }}
@@ -207,16 +207,16 @@ export default {
}
} else {
//New record so there has to be a object type and objectId in route
- // path: "/home-reviews/:recordid/:objectType?/:objectId?",
+ // path: "/home-reviews/:recordid/:aType?/:objectId?",
vm.obj.objectId = window.$gz.util.stringToIntOrNull(
vm.$route.params.objectId
);
- vm.obj.objectType = window.$gz.util.stringToIntOrNull(
- vm.$route.params.objectType
+ vm.obj.aType = window.$gz.util.stringToIntOrNull(
+ vm.$route.params.aType
);
- if (!vm.obj.objectId || !vm.obj.objectType) {
- throw "ObjectType and ObjectId are required to create a review";
+ if (!vm.obj.objectId || !vm.obj.aType) {
+ throw "AType and ObjectId are required to create a review";
}
vm.name = vm.$route.params.name;
@@ -228,7 +228,7 @@ export default {
if (!vm.name) {
vm.name = await window.$gz.api.fetchBizObjectName(
- vm.obj.objectType,
+ vm.obj.aType,
vm.obj.objectId
);
}
@@ -268,7 +268,7 @@ export default {
//I.E. Serial, usertype fields, ACTIVE
//Also, if it's a non-nullable Enum backed field then it should have a valid selection i.e. not zero if there is no zero
//{"data":{"id":2,"concurrency":1257740,"name":"Follow up on this unit","notes":"Additional text about this unit","wiki":null,"customFields":null,"tags":["completed.review","v7-import"],
- //"dueDate":"2019-03-21T22:00:00Z","completedDate":"2019-03-21T22:00:00Z","completionNotes":null,"userId":2,"assignedByUserId":1,"objectId":9,"objectType":31,"overDue":false}}
+ //"dueDate":"2019-03-21T22:00:00Z","completedDate":"2019-03-21T22:00:00Z","completionNotes":null,"userId":2,"assignedByUserId":1,"objectId":9,"aType":31,"overDue":false}}
{
id: 0,
concurrency: 0,
@@ -284,7 +284,7 @@ export default {
userId: window.$gz.store.state.userId,
assignedByUserId: window.$gz.store.state.userId,
objectId: null,
- objectType: null,
+ aType: null,
overDue: false
},
formState: {
@@ -349,7 +349,7 @@ export default {
},
iconForType() {
- return window.$gz.util.iconForType(this.obj.objectType);
+ return window.$gz.util.iconForType(this.obj.aType);
},
hasSupervisorRole: function() {
//mirrored from ReviewBiz.cs validation rule at server
@@ -372,7 +372,7 @@ export default {
methods: {
navToTarget: function() {
window.$gz.eventBus.$emit("openobject", {
- type: this.obj.objectType,
+ type: this.obj.aType,
id: this.obj.objectId
});
},
@@ -603,7 +603,7 @@ async function clickHandler(menuItem) {
name: "review-edit",
params: {
recordid: 0,
- objectType: m.vm.obj.objectType,
+ aType: m.vm.obj.aType,
objectId: m.vm.obj.objectId,
name: m.vm.name
}
@@ -624,7 +624,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.Review,
+ AType: window.$gz.type.Review,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/home-reviews.vue b/ayanova/src/views/home-reviews.vue
index 64ff34d1..39213516 100644
--- a/ayanova/src/views/home-reviews.vue
+++ b/ayanova/src/views/home-reviews.vue
@@ -2,7 +2,7 @@
@@ -32,19 +32,17 @@ export default {
window.$gz.eventBus.$on("menu-click", clickHandler);
vm.objectId = window.$gz.util.stringToIntOrNull(vm.$route.params.objectId);
- vm.objectType = window.$gz.util.stringToIntOrNull(
- vm.$route.params.objectType
- );
+ vm.aType = window.$gz.util.stringToIntOrNull(vm.$route.params.aType);
//OPTIONAL FILTER
- if (vm.objectId && vm.objectId != 0 && vm.objectType) {
+ if (vm.objectId && vm.objectId != 0 && vm.aType) {
//OBJECTID,AYATYPE
- vm.clientCriteria = `${vm.objectId},${vm.objectType}`;
+ vm.clientCriteria = `${vm.objectId},${vm.aType}`;
vm.preFilterMode = {
- icon: window.$gz.util.iconForType(vm.objectType),
+ icon: window.$gz.util.iconForType(vm.aType),
id: vm.objectId,
- ayatype: vm.objectType,
+ ayatype: vm.aType,
viz: vm.$route.params.name,
clearable: true
};
@@ -58,25 +56,24 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.Review,
selectedItems: [],
reload: false,
clientCriteria: undefined,
preFilterMode: null,
objectId: null,
- objectType: null,
+ aType: null,
name: null
};
},
// computed: {
// iconForType() {
- // return window.$gz.util.iconForType(this.objectType);
+ // return window.$gz.util.iconForType(this.aType);
// }
// },
methods: {
// navToTarget: function() {
// window.$gz.eventBus.$emit("openobject", {
- // type: this.objectType,
+ // type: this.aType,
// id: this.objectId
// });
// },
@@ -89,7 +86,7 @@ export default {
this.reload = !this.reload;
}
// iconForType() {
- // return window.$gz.util.iconForType(this.objectType, 10);
+ // return window.$gz.util.iconForType(this.aType, 10);
// }
}
};
@@ -109,7 +106,7 @@ async function clickHandler(menuItem) {
name: "review-edit",
params: {
recordid: 0,
- objectType: m.vm.objectType,
+ aType: m.vm.aType,
objectId: m.vm.objectId,
name: m.vm.name
}
@@ -178,7 +175,7 @@ function generateMenu(vm) {
};
if (vm.rights.change) {
- if (vm.objectId && vm.objectType) {
+ if (vm.objectId && vm.aType) {
menuOptions.menuItems.push({
title: "New",
icon: "$ayiPlus",
diff --git a/ayanova/src/views/home-search.vue b/ayanova/src/views/home-search.vue
index d64fdc3e..fa2f6cfe 100644
--- a/ayanova/src/views/home-search.vue
+++ b/ayanova/src/views/home-search.vue
@@ -17,7 +17,7 @@
-
+
{{ $ay.t("AuthConnectAppTitle") }}
{{
@@ -42,7 +42,7 @@
:error-messages="form().serverErrors(this, 'pin')"
ref="pin"
@input="fieldValueChanged('pin')"
- data-cy="tfaPin"
+ data-cy="tfa"
autofocus
@keyup.enter="authenticate"
>
diff --git a/ayanova/src/views/inv-part-assemblies.vue b/ayanova/src/views/inv-part-assemblies.vue
index e9188878..9f00976e 100644
--- a/ayanova/src/views/inv-part-assemblies.vue
+++ b/ayanova/src/views/inv-part-assemblies.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.PartAssembly,
+ aType: window.$gz.type.PartAssembly,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/inv-part-assembly.vue b/ayanova/src/views/inv-part-assembly.vue
index 24b1800a..7dfd3f26 100644
--- a/ayanova/src/views/inv-part-assembly.vue
+++ b/ayanova/src/views/inv-part-assembly.vue
@@ -722,7 +722,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.PartAssembly,
+ AType: window.$gz.type.PartAssembly,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/inv-part-inventory-transactions.vue b/ayanova/src/views/inv-part-inventory-transactions.vue
index 0925bb66..575822d9 100644
--- a/ayanova/src/views/inv-part-inventory-transactions.vue
+++ b/ayanova/src/views/inv-part-inventory-transactions.vue
@@ -2,7 +2,7 @@
@@ -64,9 +64,8 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.PartInventory,
objectId: null,
- objectType: null,
+ aType: null,
selectedItems: [],
clientCriteria: undefined,
preFilterMode: null,
diff --git a/ayanova/src/views/inv-part-inventory.vue b/ayanova/src/views/inv-part-inventory.vue
index c5a0e27d..a3fc5a3b 100644
--- a/ayanova/src/views/inv-part-inventory.vue
+++ b/ayanova/src/views/inv-part-inventory.vue
@@ -2,7 +2,7 @@
@@ -64,7 +64,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.PartInventory,
+ aType: window.$gz.type.PartInventory,
selectedItems: [],
clientCriteria: undefined,
preFilterMode: null,
diff --git a/ayanova/src/views/inv-part-warehouse.vue b/ayanova/src/views/inv-part-warehouse.vue
index 9d8c3455..69687f11 100644
--- a/ayanova/src/views/inv-part-warehouse.vue
+++ b/ayanova/src/views/inv-part-warehouse.vue
@@ -472,7 +472,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.PartWarehouse,
+ AType: window.$gz.type.PartWarehouse,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/inv-part-warehouses.vue b/ayanova/src/views/inv-part-warehouses.vue
index d7932742..c8961832 100644
--- a/ayanova/src/views/inv-part-warehouses.vue
+++ b/ayanova/src/views/inv-part-warehouses.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.PartWarehouse,
+ aType: window.$gz.type.PartWarehouse,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/inv-part.vue b/ayanova/src/views/inv-part.vue
index cf14848a..ea32c360 100644
--- a/ayanova/src/views/inv-part.vue
+++ b/ayanova/src/views/inv-part.vue
@@ -687,7 +687,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.Part,
+ AType: window.$gz.type.Part,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/inv-parts.vue b/ayanova/src/views/inv-parts.vue
index 17bb9a69..68d6e17a 100644
--- a/ayanova/src/views/inv-parts.vue
+++ b/ayanova/src/views/inv-parts.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.Part,
+ aType: window.$gz.type.Part,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/inv-purchase-order.vue b/ayanova/src/views/inv-purchase-order.vue
index d1323eb5..f091853e 100644
--- a/ayanova/src/views/inv-purchase-order.vue
+++ b/ayanova/src/views/inv-purchase-order.vue
@@ -1643,7 +1643,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.PurchaseOrder,
+ AType: window.$gz.type.PurchaseOrder,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/inv-purchase-orders.vue b/ayanova/src/views/inv-purchase-orders.vue
index 68edb426..5a65536b 100644
--- a/ayanova/src/views/inv-purchase-orders.vue
+++ b/ayanova/src/views/inv-purchase-orders.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.PurchaseOrder,
+ aType: window.$gz.type.PurchaseOrder,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/svc-contract.vue b/ayanova/src/views/svc-contract.vue
index b94f8a51..91b190e1 100644
--- a/ayanova/src/views/svc-contract.vue
+++ b/ayanova/src/views/svc-contract.vue
@@ -1848,7 +1848,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.Contract,
+ AType: window.$gz.type.Contract,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/svc-contracts.vue b/ayanova/src/views/svc-contracts.vue
index 3b553134..a2fefcb6 100644
--- a/ayanova/src/views/svc-contracts.vue
+++ b/ayanova/src/views/svc-contracts.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.Contract,
+ aType: window.$gz.type.Contract,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/svc-csr.vue b/ayanova/src/views/svc-csr.vue
index 045feae0..095db196 100644
--- a/ayanova/src/views/svc-csr.vue
+++ b/ayanova/src/views/svc-csr.vue
@@ -712,7 +712,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.CustomerServiceRequest,
+ AType: window.$gz.type.CustomerServiceRequest,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/svc-csrs.vue b/ayanova/src/views/svc-csrs.vue
index f297cc23..4402b105 100644
--- a/ayanova/src/views/svc-csrs.vue
+++ b/ayanova/src/views/svc-csrs.vue
@@ -2,7 +2,7 @@
@@ -36,7 +36,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.CustomerServiceRequest,
+ aType: window.$gz.type.CustomerServiceRequest,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/svc-loaner.vue b/ayanova/src/views/svc-loaner.vue
index 1e4f0e0d..d90aaf40 100644
--- a/ayanova/src/views/svc-loaner.vue
+++ b/ayanova/src/views/svc-loaner.vue
@@ -702,7 +702,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.LoanUnit,
+ AType: window.$gz.type.LoanUnit,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/svc-loaners.vue b/ayanova/src/views/svc-loaners.vue
index 52abd54e..a12c9e6f 100644
--- a/ayanova/src/views/svc-loaners.vue
+++ b/ayanova/src/views/svc-loaners.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.LoanUnit,
+ aType: window.$gz.type.LoanUnit,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/svc-project.vue b/ayanova/src/views/svc-project.vue
index 043d9e89..fbd138d6 100644
--- a/ayanova/src/views/svc-project.vue
+++ b/ayanova/src/views/svc-project.vue
@@ -552,7 +552,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.Project,
+ AType: window.$gz.type.Project,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/svc-projects.vue b/ayanova/src/views/svc-projects.vue
index 99045ff9..9d5ecbc6 100644
--- a/ayanova/src/views/svc-projects.vue
+++ b/ayanova/src/views/svc-projects.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.Project,
+ aType: window.$gz.type.Project,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/svc-unit-model.vue b/ayanova/src/views/svc-unit-model.vue
index 00e07aec..aa5f02f9 100644
--- a/ayanova/src/views/svc-unit-model.vue
+++ b/ayanova/src/views/svc-unit-model.vue
@@ -663,7 +663,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.UnitModel,
+ AType: window.$gz.type.UnitModel,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/svc-unit-models.vue b/ayanova/src/views/svc-unit-models.vue
index 179b27c7..d236addb 100644
--- a/ayanova/src/views/svc-unit-models.vue
+++ b/ayanova/src/views/svc-unit-models.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.UnitModel,
+ aType: window.$gz.type.UnitModel,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/svc-unit.vue b/ayanova/src/views/svc-unit.vue
index 42459355..d7c92723 100644
--- a/ayanova/src/views/svc-unit.vue
+++ b/ayanova/src/views/svc-unit.vue
@@ -928,7 +928,7 @@ export default {
this.$router.push({
name: "service-banks",
params: {
- objectType: window.$gz.type.Unit,
+ aType: window.$gz.type.Unit,
objectId: this.$route.params.recordid,
viz: this.obj.serial,
icon: "$ayiFan"
@@ -944,7 +944,7 @@ export default {
this.$router.push({
name: "meter-readings",
params: {
- objectType: window.$gz.type.Unit,
+ aType: window.$gz.type.Unit,
objectId: this.$route.params.recordid
}
});
@@ -1270,7 +1270,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.Unit,
+ AType: window.$gz.type.Unit,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/svc-units.vue b/ayanova/src/views/svc-units.vue
index 611803f5..639e44ea 100644
--- a/ayanova/src/views/svc-units.vue
+++ b/ayanova/src/views/svc-units.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.Unit,
+ aType: window.$gz.type.Unit,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/vendor.vue b/ayanova/src/views/vendor.vue
index f397fce0..7f916850 100644
--- a/ayanova/src/views/vendor.vue
+++ b/ayanova/src/views/vendor.vue
@@ -1054,7 +1054,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.Vendor,
+ AType: window.$gz.type.Vendor,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/vendors.vue b/ayanova/src/views/vendors.vue
index 5d9ab58a..7177f86d 100644
--- a/ayanova/src/views/vendors.vue
+++ b/ayanova/src/views/vendors.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.Vendor,
+ aType: window.$gz.type.Vendor,
selectedItems: [],
reload: false
};
diff --git a/ayanova/src/views/widget.vue b/ayanova/src/views/widget.vue
index 89981c8f..89a07473 100644
--- a/ayanova/src/views/widget.vue
+++ b/ayanova/src/views/widget.vue
@@ -618,7 +618,7 @@ async function clickHandler(menuItem) {
//general report selector chosen
let res = await m.vm.$refs.reportSelector.open({
- ObjectType: window.$gz.type.Widget,
+ AType: window.$gz.type.Widget,
selectedRowIds: [m.vm.obj.id]
});
diff --git a/ayanova/src/views/widgets.vue b/ayanova/src/views/widgets.vue
index fe3b5542..5a8cc66e 100644
--- a/ayanova/src/views/widgets.vue
+++ b/ayanova/src/views/widgets.vue
@@ -2,7 +2,7 @@
@@ -34,7 +34,7 @@ export default {
data() {
return {
rights: window.$gz.role.defaultRightsObject(),
- ayType: window.$gz.type.Widget,
+ aType: window.$gz.type.Widget,
selectedItems: [],
reload: false
};
diff --git a/ayanova/tests/e2e/specs/smoke.js b/ayanova/tests/e2e/specs/smoke.js
index 250d1a8e..e2749de4 100644
--- a/ayanova/tests/e2e/specs/smoke.js
+++ b/ayanova/tests/e2e/specs/smoke.js
@@ -13,30 +13,6 @@ describe("SMOKE", () => {
.clear()
.type(`${Cypress.env("adminpassword")}{enter}`);
- /*
-
-TODO:
-x ay-open path: "/open/:ayatype/:recordid",
-x home-memos/id edit form
-x home-remidners/id
-x home-reviews/objecttype/objectid
-x home-reset
-x cust-customer-notes/customerid
-x cust-customer-note/recordid
-XXXXx cust-users/recordid NOT WORKING, NEEDS MORE
-x inv-part-serials/id
-x inv-part-stock-levels/id
-x inv-part-adjustment (is transaction edit form)
-x acc-service-banks/recordid/objecttype/objectid
-x adm-users/id
-x adm-import
-/viewreport viewreport?oid=[objectid]&rid=[reportid]
-ay-evaluate !
-
-
-
-*/
-
//################# HOME
cy.visit("/home-dashboard");
cy.url().should("include", "/home-dashboard");
@@ -81,6 +57,10 @@ ay-evaluate !
cy.url().should("include", "/home-password");
cy.get("[data-cy=loginName]");
+ cy.visit("/home-security");
+ cy.url().should("include", "/home-security");
+ cy.get("[data-cy=tfa]");
+
//can't do this without reset code etc, just logs out
// cy.visit("/home-reset");
// cy.url().should("include", "/home-reset");
@@ -324,6 +304,10 @@ ay-evaluate !
cy.url().should("include", "/adm-global-logo");
cy.get("[data-cy=uploadSmall]");
+ cy.visit("/adm-global-seeds");
+ cy.url().should("include", "/adm-global-seeds");
+ cy.get("[data-cy=purchaseOrderNextSerial]");
+
cy.visit("/adm-license");
cy.url().should("include", "/adm-license");
cy.get("[data-cy=licenseForm]");
diff --git a/ayanova/src/api/authorizationroles.js b/ayanova/src/api/authorizationroles.js
index d01eb5c8..428283eb 100644
--- a/ayanova/src/api/authorizationroles.js
+++ b/ayanova/src/api/authorizationroles.js
@@ -96,9 +96,9 @@ export default {
};
},
/////////////////////////////////
// oType is the name of the object type as defined in ayatype.js
//
- getRights(oType) {
+ getRights(aType) {
//from bizroles.cs:
//HOW THIS WORKS / WHATS EXPECTED
//Change = CREATE, RETRIEVE, UPDATE, DELETE - Full rights
@@ -113,13 +113,13 @@ export default {
//Get the type name from the type enum value
//de-lodash
// let typeName = window.$gz. _.findKey(window.$gz.type, function(o) {
- // return o == oType;
+ // return o == aType;
// });
//my _.findKey replacement:
let typeName = undefined;
for (const [key, value] of Object.entries(window.$gz.type)) {
- if (value == oType) {
+ if (value == aType) {
typeName = key;
break;
}
@@ -129,7 +129,7 @@ export default {
let objectRoleRights = this.ROLE_RIGHTS[typeName];
if (!objectRoleRights) {
throw new Error(
- `authorizationroles::getRights type ${oType} not found in roles collection`
+ `authorizationroles::getRights type ${aType} not found in roles collection`
);
}
@@ -163,8 +163,8 @@ export default {
// convenience method for forms that deal with multiple object types
// (i.e. grids, history etc, initialization of main menu etc)
//
- canOpen(oType) {
- let r = this.getRights(oType);
+ canOpen(aType) {
+ let r = this.getRights(aType);
//convention is change might be defined but not read so canOpen is true eitehr way
return r.change == true || r.read == true;
},
@@ -172,8 +172,8 @@ export default {
// convenience method for forms that deal with multiple object types
// (i.e. grids, history etc, initialization of main menu etc)
//
- canChange(oType) {
- let r = this.getRights(oType);
+ canChange(aType) {
+ let r = this.getRights(aType);
return r.change == true;
}
};
@@ -96,9 +96,9 @@ export default {
},
/////////////////////////////////
- // oType is the name of the object type as defined in ayatype.js
+ // aType is the name of the object type as defined in ayatype.js
//